==> nextcloud-11.0.8.tar.bz2: nextcloud/apps/activity/l10n/uk.js <==
OC.L10N.register(
    "activity",
    {
    "Activities" : "Активність",
    "An error occurred while loading activities" : "Під час заванатаження подій відбулася помилка",
    "No activity yet" : "Поки що активність відсутня",
    "Load more activities" : "Завантажити більше активності",
    "Copied!" : "Скопійовано!",
    "Not supported!" : "Не підтримується!",
    "Press ⌘-C to copy." : "Натисніть ⌘-C щоб скопіювати.",
    "Press Ctrl-C to copy." : "Натисніть Ctrl-C щоб скопіювати.",
    "Home" : "Домівка",
    "{name} (invisible)" : "{name} (невидимо)",
    "{name} (restricted)" : "{name} (обмежено)",
    "in {path}" : "в {path}",
    "This stream will show events like additions, changes & shares" : "У цьому потоці будуть показані події, на кшталт доповнення, зміни та поширення",
    "There are no events for this filter" : "За цим фільтром події відсутні",
    "Today" : "Сьогодні",
    "Yesterday" : "Вчора",
    "Open file" : "Відкрити файл",
    "Personal activity feed for %s" : "Персональна стрічка оновлень для %s",
    "Your feed URL is invalid" : "Ваше посилання новинної стрічки неправильна",
    "Your settings have been updated." : "Налаштування оновлені.",
    "Settings have been updated." : "Налаштування було оновлено.",
    "Mail" : "Пошта",
    "Stream" : "Потік",
    "All activities" : "Всі дії",
    "By others" : "Іншими",
    "By you" : "Вами",
    "\"remote user\"" : "\"віддалений користувач\"",
    "Hello %s" : "Вітаємо %s",
    "Hello %s," : "Вітаємо %s,",
    "There was some activity at %s" : "Остання подія відбулася о %s",
    "_and %n more _::_and %n more _" : ["та ще %n","та ще %n","та ще %n"],
    "Activity notification" : "Повідомлення про події",
    ", " : ",",
    "%s and %s" : "%s і %s",
    "Activity" : "Ваші дії",
    "Activity feed" : "Стрічка оновлень",
    "Send activity emails" : "Надіслати активність електронною поштою",
    "Default settings" : "Налаштування по замовчуванню",
    "Configure the default activity settings for new users." : "Сконфігуруйте налаштування подій за замовчуванням для нових користувачів.",
    "List your own actions in the stream" : "Перелічіть ваші власні дії в потоці",
    "Notify about your own actions via email" : "Повідомляти про мої дії по email",
    "You need to set up your email address before you can receive notification emails." : "Для отримання повідомлень вкажіть свій e-mail в особистих налаштуваннях.",
    "Send emails:" : "Відправляти електронні повідомлення:",
    "As soon as possible" : "Якнайшвидше",
    "Hourly" : "Щогодини",
    "Daily" : "Щоденно",
    "Weekly" : "Щотижня",
    "Choose for which activities you want to get an email notification, and which should show up in the activity app stream." : "Виберіть події для яких ви хочете отримувати сповіщення поштою, і які потрібно відображати при перегляді подій (додаток Activity).",
    "Settings" : "Налаштування",
    "Enable RSS feed" : "Активувати RSS стрічку",
    "RSS feed" : "Стрічка RSS",
    "No more events to load" : "Більше немає подій для завантаження",
    "Files" : "Файли",
    "Error loading activities" : "Помилка завантаження подій",
    "No activities" : "Активність відсутня",
    "You are receiving this email because the following things happened at %s" : "Ви отримали це повідомлення, тому що о %s відбулось наступне",
    "* %1$s - %2$s" : "* %1$s - %2$s",
    "_* and %n more _::_* and %n more _" : ["* та ще %n","* та ще %n","* та ще %n"]
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");

==> nextcloud-12.0.5.tar.bz2: nextcloud/apps/activity/l10n/uk.js <==
OC.L10N.register(
    "activity",
    {
    "Activities" : "Активність",
    "An error occurred while loading activities" : "Під час заванатаження подій відбулася помилка",
    "No activity yet" : "Поки що активність відсутня",
    "Load more activities" : "Завантажити більше активності",
    "Copied!" : "Скопійовано!",
    "Not supported!" : "Не підтримується!",
    "Press ⌘-C to copy." : "Натисніть ⌘-C щоб скопіювати.",
    "Press Ctrl-C to copy." : "Натисніть Ctrl-C щоб скопіювати.",
    "{name} (invisible)" : "{name} (невидимо)",
    "{name} (restricted)" : "{name} (обмежено)",
    "in {path}" : "в {path}",
    "This stream will show events like additions, changes & shares" : "У цьому потоці будуть показані події, на кшталт доповнення, зміни та поширення",
    "There are no events for this filter" : "За цим фільтром події відсутні",
    "Today" : "Сьогодні",
    "Yesterday" : "Вчора",
    "Open file" : "Відкрити файл",
    "Personal activity feed for %s" : "Персональна стрічка оновлень для %s",
    "Your feed URL is invalid" : "Ваше посилання новинної стрічки неправильна",
    "Your settings have been updated." : "Налаштування оновлені.",
    "Settings have been updated." : "Налаштування було оновлено.",
    "Mail" : "Пошта",
    "Stream" : "Потік",
    "All activities" : "Всі дії",
    "By others" : "Іншими",
    "By you" : "Вами",
    "\"remote user\"" : "\"віддалений користувач\"",
    "Hello %s" : "Привіт %s",
    "Hello %s," : "Привіт %s,",
    "There was some activity at %s" : "Остання подія відбулася о %s",
    "Activity notification" : "Повідомлення про події",
    ", " : ",",
    "%s and %s" : "%s і %s",
    "Activity" : "Ваші дії",
    "Activity feed" : "Стрічка оновлень",
    "Send activity emails" : "Надіслати активність електронною поштою",
    "Default settings" : "Налаштування по замовчуванню",
    "Configure the default activity settings for new users." : "Сконфігуруйте налаштування подій за замовчуванням для нових користувачів.",
    "List your own actions in the stream" : "Перелічіть ваші власні дії в потоці",
    "Notify about your own actions via email" : "Повідомляти про мої дії по email",
    "You need to set up your email address before you can receive notification emails." : "Для отримання повідомлень вкажіть свій e-mail в особистих налаштуваннях.",
    "Send emails:" : "Відправляти електронні повідомлення:",
    "As soon as possible" : "Якнайшвидше",
    "Hourly" : "Щогодини",
    "Daily" : "Щоденно",
    "Weekly" : "Щотижня",
    "Choose for which activities you want to get an email notification, and which should show up in the activity app stream." : "Виберіть події для яких ви хочете отримувати сповіщення поштою, і які потрібно відображати при перегляді подій (додаток Activity).",
    "Settings" : "Налаштування",
    "Enable RSS feed" : "Активувати RSS стрічку",
    "RSS feed" : "RSS стрічка",
    "No more events to load" : "Більше немає подій для завантаження",
    "Files" : "Файли",
    "Error loading activities" : "Помилка завантаження подій",
    "No activities" : "Активність відсутня",
    "You are receiving this email because the following things happened at %s" : "Ви отримали це повідомлення, тому що о %s відбулось наступне",
    "* %1$s - %2$s" : "* %1$s - %2$s"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
